common

package
v1.0.0-preupgrade Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type EDSMetricLabeler

type EDSMetricLabeler interface {
	// With returns a new metrics labeler with the given key-value pairs.
	With(keyValues ...string) EDSMetricLabeler

	// IncrementActiveRequestsCounter increments the active requests counter.
	IncrementActiveRequestsCounter(ctx context.Context)
	// DecrementActiveRequestsCounter decrements the active requests counter.
	DecrementActiveRequestsCounter(ctx context.Context)
	// RecordHTTPRequestDuration records the HTTP request duration.
	RecordHTTPRequestDuration(ctx context.Context, duration time.Duration, path, method string, status int)

	// IncrementStoreSubscriptionUptime increments the store uptime counter.
	IncrementStoreSubscriptionUptime(ctx context.Context)
	// IncrementStoreUpdatesCounter increments the store updates counter.
	IncrementStoreUpdatesCounter(ctx context.Context)
	// RecordStoreLedgerEndGauge records the store's current ledger end.
	RecordStoreLedgerEndGauge(ctx context.Context, ledgerEnd int64)
}

EDSMetricLabeler provides all metric recording functionality for the Explicit Disclosure Server.

Jump to