Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Uint64Checked ¶
Uint64Checked parses a uint64 from a string that may have been serialized from a Daml NUMERIC.
Daml NUMERIC values are decimal strings with arbitrary precision, and may be represented with a trailing decimal point (for example "12345."). In this codebase we only accept integer-valued NUMERICs when converting into uint64.
The parsing is strict: - the value must parse as a rational number - it must be an integer (no fractional component) - it must fit into an unsigned 64-bit integer
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.